# Generated by Django 4.2.16 on 2025-02-24 21:37

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('subscriptionmanager', '0017_accountcodemap'),
    ]

    operations = [
        migrations.AddField(
            model_name='workspacesummary',
            name='is_sandbox',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='workspacesummary',
            name='is_suspended',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='workspacesummary',
            name='is_virtual_only',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='workspacesummary',
            name='timezone',
            field=models.CharField(default='', max_length=50),
        ),
    ]
